@@ -15,6 +15,9 @@ def get_logger() -> logging.Logger:
     file_path = Path(f"log/{log.name}.log")
     if not file_path.parent.exists():
         file_path.parent.mkdir()
+    if (log.hasHandlers()):
+        return log
+
     fileHandler = logging.FileHandler(file_path, 'w')
     fileHandler.setFormatter(logFormatter)
     log.addHandler(fileHandler)
@@ -22,4 +25,5 @@ def get_logger() -> logging.Logger:
     consoleHandler.setFormatter(logFormatter)
     log.addHandler(consoleHandler)
     log.propagate = False
-    return log
\ No newline at end of file
+    return log
+
